@@ -4,9 +4,8 @@ import asyncio
 import contextlib
 import random
 import ssl
-from collections.abc import Sized
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import aiohttp
 import certifi
@@ -17,11 +16,14 @@ import yaml
 
 from .version import version
 
+if TYPE_CHECKING:
+    from collections.abc import Sized
+
 DATA_DIR = Path(__file__).parents[1] / 'data'
 CONFIG_DIRS = [
+    Path('~/.theHarvester'),
     Path('/etc/theHarvester/'),
     Path('/usr/local/etc/theHarvester/'),
-    Path('~/.theHarvester'),
 ]
 
 
@@ -38,7 +40,7 @@ class Core:
 
         # Fallback to creating default in user's home dir
         default = (DATA_DIR / filename).read_text()
-        dest = CONFIG_DIRS[-1].expanduser() / filename
+        dest = CONFIG_DIRS[0].expanduser() / filename
         dest.parent.mkdir(exist_ok=True)
         dest.write_text(default)
         print(f'Created default {filename} at {dest}')
@@ -53,10 +55,6 @@ class Core:
     def bevigil_key() -> str:
         return Core.api_keys()['bevigil']['key']
 
-    @staticmethod
-    def binaryedge_key() -> str:
-        return Core.api_keys()['binaryedge']['key']
-
     @staticmethod
     def bing_key() -> str:
         return Core.api_keys()['bing']['key']
@@ -65,6 +63,10 @@ class Core:
     def bufferoverun_key() -> str:
         return Core.api_keys()['bufferoverun']['key']
 
+    @staticmethod
+    def builtwith_key() -> str:
+        return Core.api_keys()['builtwith']['key']
+
     @staticmethod
     def censys_key() -> tuple:
         return Core.api_keys()['censys']['id'], Core.api_keys()['censys']['secret']
@@ -73,6 +75,14 @@ class Core:
     def criminalip_key() -> str:
         return Core.api_keys()['criminalip']['key']
 
+    @staticmethod
+    def dehashed_key() -> str:
+        return Core.api_keys()['dehashed']['key']
+
+    @staticmethod
+    def dnsdumpster_key() -> str:
+        return Core.api_keys()['dnsdumpster']['key']
+
     @staticmethod
     def fullhunt_key() -> str:
         return Core.api_keys()['fullhunt']['key']
@@ -81,6 +91,10 @@ class Core:
     def github_key() -> str:
         return Core.api_keys()['github']['key']
 
+    @staticmethod
+    def haveibeenpwned_key() -> str:
+        return Core.api_keys()['haveibeenpwned']['key']
+
     @staticmethod
     def hunter_key() -> str:
         return Core.api_keys()['hunter']['key']
@@ -93,18 +107,22 @@ class Core:
     def intelx_key() -> str:
         return Core.api_keys()['intelx']['key']
 
+    @staticmethod
+    def leaklookup_key() -> str:
+        return Core.api_keys()['leaklookup']['key']
+
     @staticmethod
     def netlas_key() -> str:
         return Core.api_keys()['netlas']['key']
 
-    @staticmethod
-    def pentest_tools_key() -> str:
-        return Core.api_keys()['pentestTools']['key']
-
     @staticmethod
     def onyphe_key() -> str:
         return Core.api_keys()['onyphe']['key']
 
+    @staticmethod
+    def pentest_tools_key() -> str:
+        return Core.api_keys()['pentestTools']['key']
+
     @staticmethod
     def projectdiscovery_key() -> str:
         return Core.api_keys()['projectDiscovery']['key']
@@ -113,6 +131,10 @@ class Core:
     def rocketreach_key() -> str:
         return Core.api_keys()['rocketreach']['key']
 
+    @staticmethod
+    def securityscorecard_key() -> str:
+        return Core.api_keys()['securityscorecard']['key']
+
     @staticmethod
     def security_trails_key() -> str:
         return Core.api_keys()['securityTrails']['key']
@@ -121,18 +143,26 @@ class Core:
     def shodan_key() -> str:
         return Core.api_keys()['shodan']['key']
 
-    @staticmethod
-    def zoomeye_key() -> str:
-        return Core.api_keys()['zoomeye']['key']
-
     @staticmethod
     def tomba_key() -> tuple[str, str]:
         return Core.api_keys()['tomba']['key'], Core.api_keys()['tomba']['secret']
 
+    @staticmethod
+    def venacus_key() -> str:
+        return Core.api_keys()['venacus']['key']
+
     @staticmethod
     def virustotal_key() -> str:
         return Core.api_keys()['virustotal']['key']
 
+    @staticmethod
+    def whoisxml_key() -> str:
+        return Core.api_keys()['whoisxml']['key']
+
+    @staticmethod
+    def zoomeye_key() -> str:
+        return Core.api_keys()['zoomeye']['key']
+
     @staticmethod
     def proxy_list() -> list:
         keys = yaml.safe_load(Core._read_config('proxies.yaml'))
@@ -156,71 +186,101 @@ class Core:
         print('*******************************************************************')
 
     @staticmethod
-    def get_supportedengines() -> list[str | Any]:
-        supportedengines = [
-            'anubis',
+    def get_supportedengines() -> list[str]:
+        """
+        Returns a list of supported search engines.
+        """
+        return [
+            'api_endpoints',
             'baidu',
             'bevigil',
-            'binaryedge',
             'bing',
             'bingapi',
             'bufferoverun',
+            'builtwith',
             'brave',
             'censys',
             'certspotter',
             'criminalip',
             'crtsh',
+            'dehashed',
             'dnsdumpster',
             'duckduckgo',
             'fullhunt',
             'github-code',
             'hackertarget',
+            'haveibeenpwned',
             'hunter',
             'hunterhow',
             'intelx',
+            'leaklookup',
+            'linkedin',
+            'linkedin_links',
+            'netcraft',
             'netlas',
+            'omnisint',
             'onyphe',
             'otx',
             'pentesttools',
             'projectdiscovery',
+            'qwant',
             'rapiddns',
             'rocketreach',
+            'securityscorecard',
             'securityTrails',
             'sitedossier',
             'subdomaincenter',
             'subdomainfinderc99',
+            'sublist3r',
+            'threatcrowd',
             'threatminer',
             'tomba',
             'urlscan',
+            'venacus',
             'virustotal',
+            'whoisxml',
             'yahoo',
             'zoomeye',
+            'zoomeyeapi',
         ]
-        return supportedengines
 
     @staticmethod
     def get_user_agent() -> str:
         # User-Agents from https://techblog.willshouse.com/2012/01/03/most-common-user-agents/
-        # Lasted updated 7/2/23
+        # Lasted updated 5/16/25
         # TODO use bs4 to auto parse user agents
         user_agents = [
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/114.0',
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/113.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/113.0',
-            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/113.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (X11; Linux x86_64; rv:109.0) Gecko/20100101 Firefox/114.0',
-            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.5 Safari/605.1.15',
-            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:109.0) Gecko/20100101 Firefox/114.0',
-            'Mozilla/5.0 (Windows NT 10.0; rv:114.0) Gecko/20100101 Firefox/114.0',
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36 Edg/114.0.1823.43',
-            'Mozilla/5.0 (X11; Linux x86_64; rv:102.0) Gecko/20100101 Firefox/102.0',
-            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/113.0.0.0 Safari/537.36',
-            'Mozilla/5.0 (X11; Linux x86_64; rv:109.0) Gecko/20100101 Firefox/113.0',
-            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/113.0.0.0 Safari/537.36 OPR/99.0.0.0',
-            'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:109.0) Gecko/20100101 Firefox/114.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:136.0) Gecko/20100101 Firefox/136.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/133.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/133.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36 Edg/134.0.0.0',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:136.0) Gecko/20100101 Firefox/136.0',
+            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (X11; Linux x86_64; rv:136.0) Gecko/20100101 Firefox/136.0',
+            'Mozilla/5.0 (X11; Linux x86_64; rv:128.0) Gecko/20100101 Firefox/128.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:135.0) Gecko/20100101 Firefox/135.0',
+            'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:136.0) Gecko/20100101 Firefox/136.0',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/18.3.1 Safari/605.1.15',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/133.0.0.0 Safari/537.36 Edg/133.0.0.0',
+            'Mozilla/5.0 (X11; Linux x86_64; rv:135.0) Gecko/20100101 Firefox/135.0',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/18.3 Safari/605.1.15',
+            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/133.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:135.0) Gecko/20100101 Firefox/135.0',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:135.0) Gecko/20100101 Firefox/135.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 YaBrowser/25.2.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.36 OPR/117.0.0.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:128.0) Gecko/20100101 Firefox/128.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/125.0.0.0 Safari/537.36 GLS/100.10.9939.100',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/18.2 Safari/605.1.15',
+            'Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:109.0) Gecko/20100101 Firefox/115.0',
+            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36',
             'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36',
             'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:109.0) Gecko/20100101 Firefox/113.0',
             'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36 Edg/114.0.1823.51',
@@ -256,6 +316,14 @@ class Core:
             'Mozilla/5.0 (Linux; Android 7.0; Moto G (4)) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4590.2 Mobile Safari/537.36 Chrome-Lighthouse',
             'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.2 Safari/605.1.15',
             'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/111.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; rv:109.0) Gecko/20100101 Firefox/115.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.3',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/18.1.1 Safari/605.1.15',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/128.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/132.0.0.0 Safari/537.36 Edg/132.0.0.0',
+            'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:134.0) Gecko/20100101 Firefox/134.0',
+            'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36',
+            'Mozilla/5.0 (X11; Linux x86_64; rv:109.0) Gecko/20100101 Firefox/119.0',
         ]
         return random.choice(user_agents)
 
@@ -285,12 +353,12 @@ class AsyncFetcher:
                 proxy = random.choice(cls().proxy_list)
                 if params != '':
                     async with aiohttp.ClientSession(headers=headers, timeout=timeout) as session:
-                        async with session.get(url, params=params, proxy=proxy) as response:
+                        async with session.get(url, params=params, proxy=str(proxy) if proxy else None) as response:
                             await asyncio.sleep(5)
                             return await response.text() if json is False else await response.json()
                 else:
                     async with aiohttp.ClientSession(headers=headers, timeout=timeout) as session:
-                        async with session.get(url, proxy=proxy) as response:
+                        async with session.get(url, proxy=str(proxy) if proxy else None) as response:
                             await asyncio.sleep(5)
                             return await response.text() if json is False else await response.json()
             elif params == '':
@@ -315,9 +383,8 @@ class AsyncFetcher:
     @classmethod
     async def fetch(cls, session, url, params: Sized = '', json: bool = False, proxy: str = '') -> str | dict | list | bool:
         # This fetch method solely focuses on get requests
+        # Wrap in try except due to 0x89 png/jpg files
         try:
-            # Wrap in try except due to 0x89 png/jpg files
-            # This fetch method solely focuses on get requests
             if proxy != '':
                 proxy = str(random.choice(cls().proxy_list))
                 if len(params) != 0:
